from flask import jsonify
from flask_restplus import Resource, Namespace

from app.extensions import db
from app.model.hotel import Hotel
from app.model.city import City


cities = Namespace('cities')


@cities.route('')
class CitiesHandler(Resource):

    def get(self):

        cities = City.query.all()

        return jsonify([c.to_json() for c in cities])

    def post(self):

        data = self.api.payload
        
        c = City.from_json(data)
        db.session.add(c)
        db.session.commit()

        return jsonify(c.to_json())


@cities.route('/<int:id>')
class CityHandler(Resource):

    def get(self, id):
        city = City.query.filter(City.id==id).first()
        if not city:
            return self.api.abort(404, "City id {} doesn't exist".format(id))

        return jsonify(city.to_json())

    def put(self, id):

        data = self.api.payload
        city = City.query.filter(City.id==id).first()
        if not city:
            return self.api.abort(404, "City id {} doesn't exist".format(id))

        city.name = data.get('name', city.name)

        db.session.commit()

        return jsonify(city.to_json())

    def delete(self, id):

        City.query.filter(City.id==id).first().delete()
        return jsonify(True)